==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/DataMaskingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property headers Masking settings for headers
 * @property queryParams Masking settings for Url query parameters
 */
public data class DataMaskingArgs(
    public val headers: Output<List<DataMaskingEntityArgs>>? = null,
    public val queryParams: Output<List<DataMaskingEntityArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs =
        com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs.builder()
            .headers(
                headers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .queryParams(
                queryParams?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataMaskingArgs].
 */
@PulumiTagMarker
public class DataMaskingArgsBuilder internal constructor() {
    private var headers: Output<List<DataMaskingEntityArgs>>? = null

    private var queryParams: Output<List<DataMaskingEntityArgs>>? = null

    /**
     * @param value Masking settings for headers
     */
    @JvmName("qklttdjsxsylvmvg")
    public suspend fun headers(`value`: Output<List<DataMaskingEntityArgs>>) {
        this.headers = value
    }

    @JvmName("icuqmmqjrfkwsmge")
    public suspend fun headers(vararg values: Output<DataMaskingEntityArgs>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values Masking settings for headers
     */
    @JvmName("vrfrkcgjgfgjtqkd")
    public suspend fun headers(values: List<Output<DataMaskingEntityArgs>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Masking settings for Url query parameters
     */
    @JvmName("wvkxpalehuqvnqyg")
    public suspend fun queryParams(`value`: Output<List<DataMaskingEntityArgs>>) {
        this.queryParams = value
    }

    @JvmName("mbbskpxaiwqgucxj")
    public suspend fun queryParams(vararg values: Output<DataMaskingEntityArgs>) {
        this.queryParams = Output.all(values.asList())
    }

    /**
     * @param values Masking settings for Url query parameters
     */
    @JvmName("etgxanlwypbosbls")
    public suspend fun queryParams(values: List<Output<DataMaskingEntityArgs>>) {
        this.queryParams = Output.all(values)
    }

    /**
     * @param value Masking settings for headers
     */
    @JvmName("flmjuwvefcybyuui")
    public suspend fun headers(`value`: List<DataMaskingEntityArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param argument Masking settings for headers
     */
    @JvmName("eqaneaaffbfqabgw")
    public suspend fun headers(argument: List<suspend DataMaskingEntityArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Masking settings for headers
     */
    @JvmName("pokvxanlcdswbxbw")
    public suspend fun headers(vararg argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Masking settings for headers
     */
    @JvmName("rpmbwibfgtlhttqw")
    public suspend fun headers(argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataMaskingEntityArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param values Masking settings for headers
     */
    @JvmName("osovsukppaqpgpnm")
    public suspend fun headers(vararg values: DataMaskingEntityArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Masking settings for Url query parameters
     */
    @JvmName("wncufuptfpmckanb")
    public suspend fun queryParams(`value`: List<DataMaskingEntityArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryParams = mapped
    }

    /**
     * @param argument Masking settings for Url query parameters
     */
    @JvmName("oyldywdlxootgngd")
    public suspend fun queryParams(argument: List<suspend DataMaskingEntityArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParams = mapped
    }

    /**
     * @param argument Masking settings for Url query parameters
     */
    @JvmName("avfivfgrntvyvecc")
    public suspend fun queryParams(vararg argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParams = mapped
    }

    /**
     * @param argument Masking settings for Url query parameters
     */
    @JvmName("yvxyckiushgdobav")
    public suspend fun queryParams(argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataMaskingEntityArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.queryParams = mapped
    }

    /**
     * @param values Masking settings for Url query parameters
     */
    @JvmName("kteynkllpttktkyn")
    public suspend fun queryParams(vararg values: DataMaskingEntityArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryParams = mapped
    }

    internal fun build(): DataMaskingArgs = DataMaskingArgs(
        headers = headers,
        queryParams = queryParams,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/DataMaskingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property headers Masking settings for headers
 * @property queryParams Masking settings for Url query parameters
 */
public data class DataMaskingArgs(
    public val headers: Output<List<DataMaskingEntityArgs>>? = null,
    public val queryParams: Output<List<DataMaskingEntityArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs =
        com.pulumi.azurenative.apimanagement.inputs.DataMaskingArgs.builder()
            .headers(
                headers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .queryParams(
                queryParams?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataMaskingArgs].
 */
@PulumiTagMarker
public class DataMaskingArgsBuilder internal constructor() {
    private var headers: Output<List<DataMaskingEntityArgs>>? = null

    private var queryParams: Output<List<DataMaskingEntityArgs>>? = null

    /**
     * @param value Masking settings for headers
     */
    @JvmName("irjkkboqrasqaudr")
    public suspend fun headers(`value`: Output<List<DataMaskingEntityArgs>>) {
        this.headers = value
    }

    @JvmName("lwnbxqcyrpndbrbe")
    public suspend fun headers(vararg values: Output<DataMaskingEntityArgs>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values Masking settings for headers
     */
    @JvmName("hmjqfpktwkqpvcpc")
    public suspend fun headers(values: List<Output<DataMaskingEntityArgs>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Masking settings for Url query parameters
     */
    @JvmName("ggrvdcixyyhgktrs")
    public suspend fun queryParams(`value`: Output<List<DataMaskingEntityArgs>>) {
        this.queryParams = value
    }

    @JvmName("qnxswrvcgfxemect")
    public suspend fun queryParams(vararg values: Output<DataMaskingEntityArgs>) {
        this.queryParams = Output.all(values.asList())
    }

    /**
     * @param values Masking settings for Url query parameters
     */
    @JvmName("fjpsrbykbxnwjypx")
    public suspend fun queryParams(values: List<Output<DataMaskingEntityArgs>>) {
        this.queryParams = Output.all(values)
    }

    /**
     * @param value Masking settings for headers
     */
    @JvmName("nctdgwhuvypufell")
    public suspend fun headers(`value`: List<DataMaskingEntityArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param argument Masking settings for headers
     */
    @JvmName("hquafvwfkmqcirlw")
    public suspend fun headers(argument: List<suspend DataMaskingEntityArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Masking settings for headers
     */
    @JvmName("cxsoufqvrljajkrn")
    public suspend fun headers(vararg argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Masking settings for headers
     */
    @JvmName("oitvlvgfykbihvcr")
    public suspend fun headers(argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataMaskingEntityArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param values Masking settings for headers
     */
    @JvmName("pvruprtxuovqdtpv")
    public suspend fun headers(vararg values: DataMaskingEntityArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Masking settings for Url query parameters
     */
    @JvmName("nyvlhwdnrcxeitlb")
    public suspend fun queryParams(`value`: List<DataMaskingEntityArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryParams = mapped
    }

    /**
     * @param argument Masking settings for Url query parameters
     */
    @JvmName("ovojxxyrktftayop")
    public suspend fun queryParams(argument: List<suspend DataMaskingEntityArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParams = mapped
    }

    /**
     * @param argument Masking settings for Url query parameters
     */
    @JvmName("itqoevhrvuiwrade")
    public suspend fun queryParams(vararg argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataMaskingEntityArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParams = mapped
    }

    /**
     * @param argument Masking settings for Url query parameters
     */
    @JvmName("qvppxdurrkysdjhw")
    public suspend fun queryParams(argument: suspend DataMaskingEntityArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataMaskingEntityArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.queryParams = mapped
    }

    /**
     * @param values Masking settings for Url query parameters
     */
    @JvmName("uwlbvumyqqvywuab")
    public suspend fun queryParams(vararg values: DataMaskingEntityArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryParams = mapped
    }

    internal fun build(): DataMaskingArgs = DataMaskingArgs(
        headers = headers,
        queryParams = queryParams,
    )
}
